@@ -593,6 +593,7 @@ class DuneQuery:
             key_map=key_map,
         )
 
+    # TODO - THIS IS A TOTALLY DEAD ROUTE!
     @staticmethod
     def find_result_by_job(job_id: str) -> Post:
         """Returns json data for a post of type FindResultDataByResult"""
@@ -646,6 +647,71 @@ class DuneQuery:
             },
         )
 
+    def get_execution(self, job_id: str) -> Post:
+        """Returns json data for a post of type GetQueuePosition
+        This is meant to determine when query execution has completed.
+        """
+        query = """
+        query GetExecution($execution_id: String!, $query_id: Int!, $parameters: [Parameter!]!) { 
+            get_execution( 
+                execution_id: $execution_id 
+                query_id: $query_id 
+                parameters: $parameters 
+            ) { 
+                    execution_queued { 
+                    execution_id 
+                    execution_user_id 
+                    position 
+                    execution_type 
+                    created_at 
+                 } 
+                execution_running { 
+                    execution_id 
+                    execution_user_id 
+                    execution_type 
+                    started_at 
+                    created_at 
+                } 
+                execution_succeeded { 
+                    execution_id 
+                    runtime_seconds 
+                    generated_at 
+                    columns 
+                    data 
+                } 
+                execution_failed { 
+                    execution_id 
+                    type 
+                    message 
+                    metadata { 
+                    line 
+                    column 
+                    hint 
+                } 
+                    runtime_seconds 
+                    generated_at 
+                } 
+            }
+        }
+        """
+        return Post(
+            data={
+                "operationName": "GetExecution",
+                "variables": {
+                    "execution_id": job_id,
+                    "query_id": self.query_id,
+                    "parameters": [p.to_dict() for p in self.parameters],
+                },
+                "query": query,
+            },
+            # They added alot here - we have to rebuild keymap validation structure!
+            # "execution_queued": Optional[?]
+            # "execution_running": Optional[?]
+            # "execution_succeeded": Optional[?]
+            key_map={},
+        )
+
+    # TODO - THIS IS A TOTALLY DEAD ROUTE!
     @staticmethod
     def get_queue_position(job_id: str) -> Post:
         """Returns json data for a post of type GetQueuePosition
@@ -653,7 +719,7 @@ class DuneQuery:
         """
         query = """
         query GetQueuePosition($job_id: uuid!) {
-          view_queue_positions(where: {id: {_eq: $job_id}}) {
+          get_queue_position(job_id: $job_id) {
             pos
           }
           jobs_by_pk(id: $job_id) {
@@ -686,10 +752,10 @@ def execute_query_post_data(query_id: int, params: list[QueryParameter]) -> Post
             },
             "query": """
                 mutation ExecuteQuery($query_id: Int!, $parameters: [Parameter!]!) {
-                  execute_query(query_id: $query_id, parameters: $parameters) {
+                  execute_query_v2(query_id: $query_id, parameters: $parameters) {
                     job_id
                   }
                 }""",
         },
-        key_map={"execute_query": {"job_id"}},
+        key_map={"execute_query_v2": {"job_id"}},
     )
